# Parametric Modeling extension for SketchUp.
# Copyright: © 2021 Samuel Tallet <samuel.tallet arobase gmail.com>
# 
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3.0 of the License, or
# (at your option) any later version.
# 
# If you release a modified version of this program TO THE PUBLIC,
# the GPL requires you to MAKE THE MODIFIED SOURCE CODE AVAILABLE
# to the program's users, UNDER THE GPL.
# 
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
# General Public License for more details.
# 
# Get a copy of the GPL here: https://www.gnu.org/licenses/gpl.html

require 'sketchup'
require 'extensions'

# Parametric Modeling plugin namespace.
module ParametricModeling

  if Sketchup.version.to_i >= 17

    VERSION = '0.0.1'

    CODE_NAME = 'ParametricModeling'
    NAME = '参数化建模'
  
    # Initialize session storage.
    SESSION = {
      nodes_editor: {
        html_dialog_open?: false,
        html_dialog: nil
      },
      nodes: {}
    }
  
    # Register extension.
  
    extension = SketchupExtension.new(NAME, 'parametric_modeling/load.rb')
  
    extension.version     = VERSION
    extension.creator     = '作者：Samuel Tallet 汉化：liutao91.cn'
    extension.copyright   = "© 2021 Samuel Tallet"
    
    extension_features = []

    extension_features.push(
      "借助类似于Unreal引擎蓝图的节点编辑器，在SketchUp中进行参数化建模。"
    )

    extension_features.push(
      '随时修改实体参数，立即查看结果。'
    )

    extension.description = extension_features.join(' ')
  
    Sketchup.register_extension(extension, load_at_start = true)
    
  else
    UI.messagebox('参数化建模插件需要在SketchUp 2017或以上版本才能运行。')
  end

end
